aboutsummaryrefslogtreecommitdiff
path: root/discord/invite.py
diff options
context:
space:
mode:
Diffstat (limited to 'discord/invite.py')
-rw-r--r--discord/invite.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/discord/invite.py b/discord/invite.py
index 2139500c..a630b3fb 100644
--- a/discord/invite.py
+++ b/discord/invite.py
@@ -31,7 +31,7 @@ from .mixins import Hashable
from .object import Object
class Invite(Hashable):
"""Represents a Discord :class:`Guild` or :class:`Channel` invite.
Depending on the way this object was created, some of the attributes can
have a value of ``None``.
@@ -73,7 +73,7 @@ class Invite(Hashable):
How many times the invite can be used.
inviter: :class:`User`
The user who created the invite.
- channel: :class:`Channel`
+ channel: :class:`abc.GuildChannel`
The channel the invite is for.
"""
@@ -31,7 +31,7 @@ from .mixins import Hashable
from .object import Object
class Invite(Hashable):
- """Represents a Discord :class:`Guild` or :class:`Channel` invite.
+ """Represents a Discord :class:`Guild` or :class:`abc.GuildChannel` invite.
Depending on the way this object was created, some of the attributes can
have a value of ``None``.